@@ -49,6 +49,18 @@ NODE_RESERVED_NAMES_CONST <- c( 'AddChild',
 #' 
 #' @description \code{Node} is at the very heart of the \code{data.tree} package. All trees are constructed
 #' by tying toghether \code{Node} objects.
+#' 
+#' @details Assemble \code{Node} objects into a \code{data.tree}
+#' structure and use the traversal methods to set, get, and perform operations on it. Typically, you construct larger tree 
+#' structures by converting from \code{data.frame}, \code{list}, or other formats.
+#' As \code{Node} is object oriented, there are always two variations of methods:
+#' \itemize{
+#'   \item a.) OO style: \code{acme$Sort()}
+#'   \item b.) traditional: \code{Sort(acme)}
+#' }
+#' This is only syntactical sugar, and the result of both variations is exactly the same. Other examples where this apply are \code{Set},
+#' \code{Get}, \code{Do}, \code{Prune}, \code{Climb}, \code{Sort}, etc.
+#' 
 #' @docType class
 #' @importFrom R6 R6Class
 #' @field children A list of child \code{Nodes}
@@ -58,10 +70,13 @@ NODE_RESERVED_NAMES_CONST <- c( 'AddChild',
 #' \describe{
 #'   \item{\code{Node$new(name)}}{Creates a new \code{Node} called \code{name}. Often used to construct the root when creating trees programmatically.}
 #'   \item{\code{AddChild(name)}}{Creates a new \code{Node} called \code{name} and adds it to this \code{Node} as a child.}
+#'   \item{\code{AddChildNode(node)}}{Adds a \code{Node} as a child.}
+#'   \item{\code{AddSibling(name)}}{Creates a new \code{Node} called \code{name} and adds it after this \code{Node} as a sibling.}
+#'   \item{\code{AddSiblingNode(sibling)}}{Adds a new \code{Node} after this \code{Node}, as a sibling.}      
 #'   \item{\code{RemoveChild(name)}}{Remove the child \code{Node} called \code{name} from a \code{Node} and returns it.}
-#'   \item{\code{RemoveAttribute(name)}}{Removes attribute called \code{name} from this \code{Node}.}
+#'   \item{\code{RemoveAttribute(name, stopIfNotAvailable)}}{Removes attribute called \code{name} from this \code{Node}. Gives an error if \code{stopIfNotAvailable} and the attribute doesn't exist.}
 #'   \item{\code{\link{Climb}(...)}}{Find a node with path \code{...}, where the \code{...} arguments are the \code{name}s of the \code{Node}s, or other field values.}
-#'   \item{\code{\link{Get}(attribute, ..., traversal = c("pre-order", "post-order", "in-order", "level", "ancestor"), pruneFun = NULL, filterFun = NULL, format = NULL, inheritFromAncestors = FALSE)}}{Traverses the tree and collects values along the way.}
+#'   \item{\code{\link{Get}(attribute, ..., traversal = c("pre-order", "post-order", "in-order", "level", "ancestor"), pruneFun = NULL, filterFun = NULL, format = NULL, inheritFromAncestors = FALSE, simplify = c(TRUE, FALSE, "array", "regular"))}}{Traverses the tree and collects values along the way.}
 #'   \item{\code{\link{Do}(fun, ..., traversal = c("pre-order", "post-order", "in-order", "level", "ancestor"), pruneFun = NULL, filterFun = NUL)}}{Traverses the tree and call fun on each node.}
 #'   \item{\code{\link{Set}(..., traversal = c("pre-order", "post-order", "in-order", "level", "ancestor"), pruneFun = NULL, filterFun = NULL)}}{Traverses the tree and assigns the args along the way, recycling the args.}
 #'   \item{\code{\link{Sort}(attribute, ..., decreasing = FALSE, recursive = TRUE}}{Sort children of a node with respect to an attribute (field, method, active, function)}
@@ -85,18 +100,25 @@ NODE_RESERVED_NAMES_CONST <- c( 'AddChild',
 #'  \item{\code{levelName}}{Returns the name of the \code{Node}, preceded by level times '*'. Useful for printing.}
 #'  \item{\code{leafCount}}{Returns the number of leaves are below a \code{Node} }
 #'  \item{\code{leaves}}{Returns a list containing all the leaf \code{Node}s }
-#'  \item{\code{level}}{Returns an integer representing the level of a \code{Node}. For example, the root has level 0.}
+#'  \item{\code{level}}{Returns an integer representing the level of a \code{Node}. For example, the root has level 1.}
 #'  \item{\code{height}}{Returns max(level) of any of the \code{Nodes} of the tree}
 #'  \item{\code{averageBranchingFactor}}{Returns the average number of crotches below this \code{Node}}
 #'  \item{\code{root}}{Returns the root \code{Node} of a \code{Node}'s tree}
 #'  \item{\code{siblings}}{Returns a list of the siblings of this \code{Node}}
 #'  
 #' }
+#' 
+#' @usage # n1 <- Node$new("Node 1")
 #'
 #' @examples
 #' library(data.tree)
 #' acme <- Node$new("Acme Inc.")
-#' accounting <- acme$AddChild("Accounting")
+#' accounting <- acme$AddChild("Accounting")$
+#'               AddSibling("Research")$
+#'               AddChild("New Labs")$
+#'               parent$
+#'               AddSibling("IT")$
+#'               AddChild("Outsource")
 #' print(acme)
 #' 
 #' @seealso For more details see the \code{\link{data.tree}} documentations, or the \code{data.tree} vignette: \code{vignette("data.tree")}
@@ -135,6 +157,21 @@ Node <- R6Class("Node",
                       },
                       
                       
+                      AddSibling = function(name, ...) {
+                        sibling <- Node$new(as.character(name), ...)
+                        invisible (self$AddSiblingNode(sibling))
+                      },
+                      
+                      AddSiblingNode = function(sibling) {
+                        if(self$isRoot) stop("Cannot insert sibling to root!")
+                        self$parent[[sibling$name]] <- sibling
+                        self$parent$children <- append(self$parent$children, sibling, after = self$position)
+                        names(self$parent$children)[self$position + 1] <- sibling$name
+                        sibling$parent <- self$parent
+                        invisible (sibling)
+                      },
+                      
+                      
                       RemoveChild = function(name) {
                         if (!name %in% names(self$children)) stop(paste0("Node ", self$name, " does not contain child ", name))
                         child <- self$children[[name]]
@@ -144,9 +181,14 @@ Node <- R6Class("Node",
                         return (child)
                       },
                       
-                      RemoveAttribute = function(name) {
-                        if (!name %in% ls(self)) stop(paste0("Node ", self$name, " does not contain field ", name))
-                        rm(list = name, envir = self)
+                      RemoveAttribute = function(name, stopIfNotAvailable = TRUE) {
+                        attAvailable <- name %in% ls(self)
+                        if (stopIfNotAvailable && !attAvailable) stop(paste0("Node ", self$name, " does not contain field ", name))
+                        else if (attAvailable) {
+                          rm(list = name, envir = self)
+                          return (TRUE)
+                        }
+                        return (FALSE)
                       },
                       
                       
@@ -188,7 +230,8 @@ Node <- R6Class("Node",
                                      pruneFun = NULL,
                                      filterFun = NULL, 
                                      format = NULL,
-                                     inheritFromAncestors = FALSE) {
+                                     inheritFromAncestors = FALSE,
+                                     simplify = c(TRUE, FALSE, "array", "regular")) {
                         
                         t <- Traverse(self, 
                                       traversal = traversal, 
@@ -198,7 +241,8 @@ Node <- R6Class("Node",
                             attribute, 
                             ...,  
                             format = format, 
-                            inheritFromAncestors = inheritFromAncestors)
+                            inheritFromAncestors = inheritFromAncestors,
+                            simplify = simplify)
 
                       },
                       
