@@ -77,6 +77,34 @@ test_that("ToDataFrame sub-tree", {
 })
 
 
+test_that("ToDataFrameTypeCol level", {
+  data(acme)
+  acme$IT$Outsource$AddChild("India")
+  acme$IT$Outsource$AddChild("Poland")
+  
+  acmedf <- ToDataFrameTypeCol(acme)
+  expect_equal(names(acmedf), c('level_1', 'level_2', 'level_3', 'level_4'))
+  expect_true( all(acmedf$level_1 == 'Acme Inc.'))
+  expect_equal(acmedf$level_2, c('Accounting', 'Accounting', 'Research', 'Research', 'IT', 'IT', 'IT', 'IT'))
+  expect_equal(acmedf$level_3, c('New Software', 'New Accounting Standards', 'New Product Line', 'New Labs', 'Outsource', 'Outsource', 'Go agile', 'Switch to R'))
+  expect_equal(acmedf$level_4, c(NA, NA, NA, NA, 'India', 'Poland', NA, NA))  
+})
+
+test_that("ToDataFrameTypeCol type", {
+  data(acme)
+  acme$IT$Outsource$AddChild("India")
+  acme$IT$Outsource$AddChild("Poland")
+  acme$Set(type = c('company', 'department', 'project', 'project', 'department', 'project', 'project', 'department', 'program', 'project', 'project', 'project', 'project'))
+  
+  acmedf <- ToDataFrameTypeCol(acme, type = 'type', prefix = NULL)
+  expect_equal(names(acmedf), c('company', 'department', 'program', 'project'))
+  expect_true( all(acmedf$company == 'Acme Inc.'))
+  expect_equal(acmedf$department, c('Accounting', 'Accounting', 'Research', 'Research', 'IT', 'IT', 'IT', 'IT'))
+  expect_equal(acmedf$program, c(NA, NA, NA, NA, 'Outsource', 'Outsource', NA, NA))  
+  expect_equal(acmedf$project, c('New Software', 'New Accounting Standards', 'New Product Line', 'New Labs', 'India', 'Poland', 'Go agile', 'Switch to R'))
+})
+
+
 test_that("FromDataFrameTable col-levels", {
   data(acme)
   acme$Set(floor = c(1, 2, 3),  filterFun = function(x) x$level == 2)
@@ -128,3 +156,6 @@ test_that("FromDataFrameNetwork order", {
 })
 
 
+
+
+
